
# Swissmetro Examples

**Example Data**

The Swissmetro sample dataset is the same data used in Biogeme examples.

You can use this data to reproduce the example models from Biogeme, and
several examples are provided here to do so.

```{toctree}
:glob:

1*
```
